<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableV2 v-bind="proTableProps" :columns="column" :operationBtns="operationBtns">
      </ProTableV2>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import { AppContainer, useTable, ProTableV2, defineOperationBtns } from '@bole-core/components';
import { OrderInputType } from '@bole-core/core';
import * as informationServices from '@/services/api/Information';

defineOptions({
  name: 'RewardGrantRecordView',
});

const column: API.CustomModuleColumnDto[] = [
  {
    id: '1',
    enCode: 'batchBillNo',
    name: '申报批次号',
  },
  {
    id: '2',
    enCode: 'changeType',
    name: '奖励金发放日期',
  },
  {
    id: '3',
    enCode: 'creationTime',
    name: '奖励金到账日期',
  },
  {
    id: '4',
    enCode: 'effectTime',
    name: '发放金额',
  },
  {
    id: '5',
    enCode: 'insurePersonNumber',
    name: '到账确认结果',
  },
];

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'previewBtn',
      name: '查看凭证',
    },
    emits: {
      onClick: (role) => handlePreview(role),
    },
  },
]);

const route = useRoute();
const router = useRouter();
const id = route.params.id as string;
const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.GetInformationForManageInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
      };
      let res = await informationServices.getInformationForManage(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      orderInput: [{ property: 'creationTime', order: OrderInputType.Desc }],
    },
  }
);

function handlePreview(row: API.InsureBatchBillDto) {}

onMounted(async () => {
  await getList();
  state.loading = false;
});
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
